====================
Project contributors
====================

 * Jonathan Stoppani <jonathan@stoppani.name>
 * Ulrich Petri <github@ulo.pe>
 * Timothy Allen (https://github.com/FlipperPA)
 * Bastien Vallet (https://github.com/Djailla)
 
